# Welcome to the Random Events package!

Probabilistic Machine Learning frequently requires descriptions of random variables and events
that are shared among many packages.
This package provides a common interface for describing random variables and events, using
usable and easily extensible classes.

## Installation:
### For Users:

Install the package via

```
pip install random-events
```

### For Developers:

Create your own fork of the [original repository](https://github.com/tomsch420/random-events) and clone the fork.
```
git clone *ADDRESS_OF_YOUR_FORK*
```

Move into the repository and initialize the submodules.
```
cd random-events
git submodule update --init --recursive
```

Now, install all requirements.
```
pip install -r requirements-dev.txt
```

## Usage and Guides:
Check out the [documentation.](https://random-events.readthedocs.io/en/latest/)
